/*
 * SPDX-FileCopyrightText: 2025 Max Mehl <https://mehl.mx>
 *
 * SPDX-License-Identifier: GPL-3.0-only
 */

:root {
  --pico-form-element-spacing-vertical: 0.2rem;
  --pico-form-element-spacing-horizontal: 0.2rem;
}

main {
  min-height: 84vh;
}

footer {
  font-size: 0.9rem;
}

ul.files li {
  padding: 0.2rem 0;
}

audio,
video {
  width: 800px;
}

#user-info {
  position: absolute;
  top: 1rem;
  right: 1rem;

  button {
    font-size: 0.9rem;
  }
}

#playlist li {

  .track {
    cursor: pointer;

    &:hover {
      font-weight: bold;
    }
  }

  &.active {
    font-weight: bold;

    &::before {
      content: "▶️ ";
    }
  }
}
