{% extends "base.html" %}

{% block content %}
<h2>Login</h2>
{% if error %}
<p style="color: red">{{ error }}</p>
{% endif %}
<form method="post">
  {{ form.csrf_token }}
  {{ form.username.label }}
  {{ form.username() }}
  {{ form.password.label }}
  {{ form.password() }}
  <button type="submit">Login</button>
</form>
{% endblock %}
